rename some RAN conn related stuff to ran_conn_*

Following previous rename of gsm_subscriber_connection:

Some functions and #defines are still called like "msc_conn" or just "msc_",
while they are clearly about a RAN conn.

To avoid confusion with the future separate concepts of MSC roles and a RAN
connection, rename all those to match the common "ran_conn" prefix.

Change-Id: Ia17a0a35f11911e00e19cafb5d7828d729a69640
diff --git a/src/libmsc/subscr_conn.c b/src/libmsc/subscr_conn.c
index b1c8bc9..5fab1c6 100644
--- a/src/libmsc/subscr_conn.c
+++ b/src/libmsc/subscr_conn.c
@@ -94,7 +94,7 @@
 	if (conn->complete_layer3_type == COMPLETE_LAYER3_CM_SERVICE_REQ
 	    && conn_accepted) {
 		conn->received_cm_service_request = true;
-		ran_conn_get(conn, MSC_CONN_USE_CM_SERVICE);
+		ran_conn_get(conn, RAN_CONN_USE_CM_SERVICE);
 	}
 
 	if (conn_accepted)
@@ -163,7 +163,7 @@
 	}
 }
 
-int msc_classmark_request_then_cipher_mode_cmd(struct ran_conn *conn, bool umts_aka,
+int ran_conn_classmark_request_then_cipher_mode_cmd(struct ran_conn *conn, bool umts_aka,
 					       bool retrieve_imeisv)
 {
 	int rc;
@@ -190,14 +190,14 @@
 		 * So far though, the only time we send a Classmark Request is during Ciphering. As soon
 		 * as more such situations arise, we need to add state to indicate what action should
 		 * follow after a Classmark Update is received (e.g.
 		 * msc_classmark_request_then_cipher_mode_cmd() sets an enum value to indicate that
 		 * Ciphering should continue afterwards). But right now, it is accurate to always
 		 * continue with Ciphering: */
 
 		/* During Ciphering, we needed Classmark information. The Classmark Update has come in,
 		 * go back into the Set Ciphering Command procedure. */
 		osmo_fsm_inst_state_chg(fi, RAN_CONN_S_AUTH_CIPH, RAN_CONN_TIMEOUT, 0);
-		if (msc_geran_set_cipher_mode(conn, conn->geran_set_cipher_mode.umts_aka,
+		if (ran_conn_geran_set_cipher_mode(conn, conn->geran_set_cipher_mode.umts_aka,
 					      conn->geran_set_cipher_mode.retrieve_imeisv)) {
 			LOGPFSML(fi, LOGL_ERROR,
 				 "Sending Cipher Mode Command failed, aborting attach\n");
@@ -341,13 +341,13 @@
 	/* Use count for either conn->a.waiting_for_clear_complete or
 	 * conn->iu.waiting_for_release_complete. 'get' it early, so we don't deallocate after tearing
 	 * down active transactions. Safeguard against double-get (though it shouldn't happen). */
-	if (!ran_conn_used_by(conn, MSC_CONN_USE_RELEASE))
-		ran_conn_get(conn, MSC_CONN_USE_RELEASE);
+	if (!ran_conn_used_by(conn, RAN_CONN_USE_RELEASE))
+		ran_conn_get(conn, RAN_CONN_USE_RELEASE);
 
 	/* Cancel pending CM Service Requests */
 	if (conn->received_cm_service_request) {
 		conn->received_cm_service_request = false;
-		ran_conn_put(conn, MSC_CONN_USE_CM_SERVICE);
+		ran_conn_put(conn, RAN_CONN_USE_CM_SERVICE);
 	}
 
 	/* Cancel all VLR FSMs, if any */
@@ -693,7 +693,7 @@
 	}
 	if (*flag) {
 		*flag = false;
-		ran_conn_put(conn, MSC_CONN_USE_RELEASE);
+		ran_conn_put(conn, RAN_CONN_USE_RELEASE);
 	}
 }
@@ -190,14 +190,14 @@
 		 * as more such situations arise, we need to add state to indicate what action should
 		 * follow after a Classmark Update is received (e.g.
-		 * msc_classmark_request_then_cipher_mode_cmd() sets an enum value to indicate that
+		 * ran_conn_classmark_request_then_cipher_mode_cmd() sets an enum value to indicate that
 		 * Ciphering should continue afterwards). But right now, it is accurate to always
 		 * continue with Ciphering: */